pub struct ListPreparedStatementsFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to ListPreparedStatements.
Lists the prepared statements in the specified workgroup.
Implementations
Sourceimpl ListPreparedStatementsFluentBuilder
impl ListPreparedStatementsFluentBuilder
Sourcepub fn as_input(&self) -> &ListPreparedStatementsInputBuilder
pub fn as_input(&self) -> &ListPreparedStatementsInputBuilder
Access the ListPreparedStatements as a reference.
Sourcepub async fn send(
self,
) -> Result<ListPreparedStatementsOutput, SdkError<ListPreparedStatementsError, HttpResponse>>
pub async fn send( self, ) -> Result<ListPreparedStatementsOutput, SdkError<ListPreparedStatementsError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<ListPreparedStatementsOutput, ListPreparedStatementsError, Self>
pub fn customize( self, ) -> CustomizableOperation<ListPreparedStatementsOutput, ListPreparedStatementsError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> ListPreparedStatementsPaginator
pub fn into_paginator(self) -> ListPreparedStatementsPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The workgroup to list the prepared statements for.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The workgroup to list the prepared statements for.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The workgroup to list the prepared statements for.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of results to return in this request.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of results to return in this request.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of results to return in this request.