#[non_exhaustive]pub struct ListPreparedStatementsOutputBuilder { /* private fields */ }Expand description
A builder for ListPreparedStatementsOutput.
Implementations
Sourceimpl ListPreparedStatementsOutputBuilder
impl ListPreparedStatementsOutputBuilder
Sourcepub fn prepared_statements(self, input: PreparedStatementSummary) -> Self
pub fn prepared_statements(self, input: PreparedStatementSummary) -> Self
Appends an item to prepared_statements.
To override the contents of this collection use set_prepared_statements.
The list of prepared statements for the workgroup.
Sourcepub fn set_prepared_statements(
self,
input: Option<Vec<PreparedStatementSummary>>,
) -> Self
pub fn set_prepared_statements( self, input: Option<Vec<PreparedStatementSummary>>, ) -> Self
The list of prepared statements for the workgroup.
Sourcepub fn get_prepared_statements(&self) -> &Option<Vec<PreparedStatementSummary>>
pub fn get_prepared_statements(&self) -> &Option<Vec<PreparedStatementSummary>>
The list of prepared statements for the workgroup.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn build(self) -> ListPreparedStatementsOutput
pub fn build(self) -> ListPreparedStatementsOutput
Consumes the builder and constructs a ListPreparedStatementsOutput.